#!/bin/bash
#
#
# Licensed Materials - Property of IBM
# 5724-F75
# (C) Copyright IBM Corp.  2003
# All Rights Reserved
# US Government Users Restricted Rights -Use, duplication or 
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#
#

LAUNCHTITLE=$0
LOGSDIR=$HOME/logs
OUTFILE=$LOGSDIR/uninstall_All_TCDrivers.log

rm -f $OUTFILE >> /dev/null

if [ $? = "1" ]; then
   echo "Can't create log file $OUTFILE" 2>&1 | tee -a $OUTFILE
   exit 1
else
   echo "Creating log file $OUTFILE" 2>&1 | tee -a $OUTFILE
fi

echo "STARTING $LAUNCHTITLE" 2>&1 | tee -a $OUTFILE

case `uname` in
   Linux)
      OS_TYPE=Linux
      EXTENSIONTYPE=sh
      INFILENAME=uninstall_All_TCDrivers-Linux.in
      echo "Executing script on $OS_TYPEx" 2>&1 | tee -a $OUTFILE
      ;;
   CYGWIN_NT-5.0|CYGWIN_NT-5.1)
      OS_TYPE=Windows
      EXTENSIONTYPE=cmd
      INFILENAME=uninstall_All_TCDrivers-Windows.in
      echo "Executing script on $OS_TYPE" 2>&1 | tee -a $OUTFILE
      ;;
   SunOS)
      OS_TYPE=Solaris
      EXTENSIONTYPE=sh
      INFILENAME=uninstall_All_TCDrivers-Solaris.in
      echo "Executing script on $OS_TYPE" 2>&1 | tee -a $OUTFILE
      ;;
   AIX)
      OS_TYPE=AIX
      EXTENSIONTYPE=sh
      INFILENAME=tio-uninstall-aix.in
      echo "Executing script on $OS_TYPE" 2>&1 | tee -a $OUTFILE
      ;;
   *)
      echo "Operating System not determined, exiting" 2>&1 | tee -a $OUTFILE
      exit 1
      ;;
esac

echo "*****************" 2>&1 | tee -a $OUTFILE
echo "START: PRE-EXECUTION DRIVER LIST" 2>&1 | tee -a $OUTFILE
$HOME/tools/tc-driver-manager.$EXTENSIONTYPE listAllStr 2>&1 | tee -a $OUTFILE
echo "END: PRE-EXECUTION DRIVER LIST" 2>&1 | tee -a $OUTFILE
echo "*****************" 2>&1 | tee -a $OUTFILE
echo "" 2>&1 | tee -a $OUTFILE

while read DRIVER
  do
     echo "*****************" 2>&1 | tee -a $OUTFILE
     echo "START UNINSTALL: $DRIVER" 2>&1 | tee -a $OUTFILE

     STATUS=`$HOME/tools/tc-driver-manager.$EXTENSIONTYPE getDriverStatus $DRIVER | tail -1`
     if [ "$STATUS" = "installed" ]; then
        echo "STATUS: installed" 2>&1 | tee -a $OUTFILE
        $HOME/tools/tc-driver-manager.$EXTENSIONTYPE uninstallDriver "$DRIVER" 2>&1 | tee -a $OUTFILE
     else
        echo "STATUS: uninstalled, skipping" 2>&1 | tee -a $OUTFILE

     fi
     
     echo "END UNINSTALL: $DRIVER" 2>&1 | tee -a $OUTFILE
     echo "*****************" 2>&1 | tee -a $OUTFILE
     echo "" 2>&1 | tee -a $OUTFILE

  done < $INFILENAME

echo "End of $LAUNCHTITLE" 2>&1 | tee -a $OUTFILE

echo "*****************" 2>&1 | tee -a $OUTFILE
echo "START: POST-EXECUTION DRIVER LIST" 2>&1 | tee -a $OUTFILE
$HOME/tools/tc-driver-manager.$EXTENSIONTYPE listAllStr 2>&1 | tee -a $OUTFILE
echo "END: POST-EXECUTION DRIVER LIST" 2>&1 | tee -a $OUTFILE
echo "*****************" 2>&1 | tee -a $OUTFILE
echo "" 2>&1 | tee -a $OUTFILE
